<?php

namespace Elementor\Modules\AtomicWidgets\CacheValidity;

use Elementor\Modules\AtomicWidgets\Styles\CacheValidity\Cache_Validity as New_Cache_Validity;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// TODO: Remove this class after 3.37 is released.
/**
 * @deprecated 3.35 Use \Elementor\Modules\AtomicWidgets\Styles\CacheValidity\Cache_Validity instead.
 */
class Cache_Validity extends New_Cache_Validity {}
